CanvasMessageModel class

Inheritance

Constructors

CanvasMessageModel({required CanvasMessagePayloadModel payload, required String hash, required String conversationKey, required String peerKey, required String deviceKey, required DateTime sentAt, List<MessageNetworkMediaModel> attachments = const []})
const

Properties

attachments List<MessageNetworkMediaModel>
finalinherited
canvasId String
no setter
conversationKey String
finalinherited
deviceKey String
finalinherited
displayText String
no setteroverride
docs List<MessageNetworkMediaModel>
no setterinherited
hash String
finalinherited
hashCode int
The hash code for this object.
no setterinherited
images List<MessageNetworkMediaModel>
no setterinherited
isCurrentPeer bool
no setterinherited
isNote bool
no setterinherited
payload CanvasMessagePayloadModel
finalinherited
peerKey String
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sentAt DateTime
finalinherited
type MessageTypes
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Json
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited