ConversationParticipantModel class

Constructors

ConversationParticipantModel({required String conversationKey, required String peerKey})
ConversationParticipantModel.fromJson(Map<String, dynamic> json)
factory

Properties

conversationKey String
final
hashCode int
The hash code for this object.
no setterinherited
key String
no setter
peerKey String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? conversationKey, String? peerKey}) ConversationParticipantModel
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

getKey(String conversationKey, String peerKey) String