Dune class final

Host-provided configuration for the Dune core runtime.

Constructors

Dune()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

directoryConfig DirectoryConfig
no setter
isConfigured bool
no setter
isStarted bool
no setter
secretStore → SecretStorage
no setter

Static Methods

configure({SecretStorage? secretStore, DirectoryConfig? directoryConfig}) → void
start() Future<void>
Starts the runtime.

Constants

admin → const AdminApi
canvas → const CanvasApi
conversations → const ConversationsApi
devices → const DevicesApi
logs → const LogsApi
media → const MediaApi
messages → const MessagesApi
network → const NetworkApi
peers → const PeersApi
posts → const PostsApi
runtime → const RuntimeApi
spaces → const SpacesApi