FixedDirectoryConfig class final

Fixed host-provided storage paths used by tests and custom hosts.

Implemented types

Constructors

FixedDirectoryConfig({required String applicationSupportPathValue, required String applicationDocumentsPathValue})

Properties

applicationDocumentsPathValue String
final
applicationSupportPathValue String
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

applicationDocumentsPath() Future<String>
Returns the path for durable user-facing documents such as stored media.
override
applicationSupportPath() Future<String>
Returns the path for durable app support data such as databases.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited