MessageModel<T extends MessagePayloadModel> class abstract

Implementers

Constructors

MessageModel({required MessageTypes type, required String hash, required String conversationKey, required String peerKey, required String deviceKey, required DateTime sentAt, required T payload, List<MessageNetworkMediaModel> attachments = const []})
const

Properties

attachments List<MessageNetworkMediaModel>
final
conversationKey String
final
deviceKey String
final
displayText String
no setter
docs List<MessageNetworkMediaModel>
no setter
hash String
final
hashCode int
The hash code for this object.
no setteroverride
images List<MessageNetworkMediaModel>
no setter
isCurrentPeer bool
no setter
isNote bool
no setter
payload → T
final
peerKey String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sentAt DateTime
final
type MessageTypes
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Json
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Json json) MessageModel<MessagePayloadModel>
fromPayload(MessagePayloadModel payload, {required String peerKey, required String conversationKey, required String hash, required String deviceKey, required DateTime sentAt, required List<MessageNetworkMediaModel> attachments}) MessageModel<MessagePayloadModel>