MessageNetworkMediaModel class

Inheritance

Constructors

MessageNetworkMediaModel({required String messageHash, required String hash, required String mime, required int size, String? name, String? blurhash})
const
MessageNetworkMediaModel.fromJson(Map<String, dynamic> json)
factory
MessageNetworkMediaModel.fromMedia(String messageHash, NetworkMediaModel media)
factory

Properties

blurhash String?
finalinherited
displayName String
no setterinherited
hash String
finalinherited
hashCode int
The hash code for this object.
no setterinherited
isImage bool
no setterinherited
messageHash String
final
mime String
finalinherited
name String?
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size int
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited