MessageReceiptModel class

Constructors

MessageReceiptModel({required String signature, required String hash, required String deviceKey, required MessageReceiptStatus status, required DateTime timestamp, required DateTime updatedAt})
MessageReceiptModel.fromJson(Map<String, dynamic> json)
factory

Properties

deviceKey String
final
hash String
final
hashCode int
The hash code for this object.
no setteroverride
id String
no setter
isCurrentDevice bool
no setter
isDelivered bool
no setter
isRead bool
no setter
isSent bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
signature String
final
status MessageReceiptStatus
final
timestamp DateTime
final
updatedAt DateTime
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited
verify() Future<bool>

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

create({required String hash, required MessageReceiptStatus status}) Future<MessageReceiptModel>
getMessage({required String hash, required MessageReceiptStatus status, required DateTime timestamp}) String