dune_core_protocol library

Classes

CanvasHlc
CanvasHlcGenerator
CanvasModel
CanvasObjectRecordModel
CanvasRegisterClockModel
A signed merge clock for a single canvas object register.
CanvasSyncErrorModel
CanvasSyncMetadataPayloadModel
CanvasSyncObjectPayloadModel
CanvasSyncRequestModel
CanvasSyncResponseModel
ConversationReceiptsRequestModel
ConversationReceiptsResponseModel
DeleteMessageEventBodyModel
DeviceAuthEventBodyModel
DeviceIdentityEventBodyModel
DeviceRequestBindingModel
DeviceRevokeEventBodyModel
DeviceSelfRevokeEventBodyModel
A device has self-revoked itself from the tailnet. This is similar to DeviceRevokeEventBodyModel, except that it doesn't require peer-verification since any device is authorized to revoke itself.
DraftEventModel<T extends EventBodyModel>
EventBodyModel
EventModel<T extends EventBodyModel>
MessageEventBodyModel
The body of a message event. The message's payload is encrypted in payload using a one-time symmetric encryption key.
MessageReactionEventBodyModel
MessageReceiptModel
PeerIdentityEventBodyModel
PeerRevokeEventBodyModel
A peer has been revoked from the tailnet. All of the peer's devices are revoked from the network and no future devices identifying as this peer will be permitted to join.
PostEventBodyModel
ProtocolDomains
Signed or KDF domain strings that are part of the wire contract.
ProtocolVersions
Version constants for Dune wire-format surfaces.
SpaceIdentityEventBodyModel

Functions

canonicalJsonEncode(Object? value) String
Encodes the restricted Dune Canonical JSON v1 profile.
canonicalJsonFromString(String source) String
Parses source and re-encodes it using Dune Canonical JSON v1.