CanvasHlc class

Implemented types
Annotations
  • @immutable

Constructors

CanvasHlc({required DateTime timestampUtc, required int logicalCounter})
CanvasHlc.parse(String value)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
logicalCounter int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timestampUtc DateTime
final

Methods

compareTo(CanvasHlc other) int
Compares this object to another object.
override
encode() String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

compareCanonicalStrings(String a, String b) int
isCanonical(String value) bool