CanvasStateSyncRepository class final

Current-state synchronization for canvases.

This repository deliberately syncs projected canvas state, not edit history. Local writes and peer sync both hydrate canvases from the current object rows plus the winning register clocks needed for deterministic LWW merges.

Constructors

CanvasStateSyncRepository()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

apply(CanvasSyncResponseModel response, {required String conversationKey, required String canvasId}) Future<bool>
changedObjectIds(String conversationKey, {required String canvasId, required Map<String, String> observedActorHlcWatermarks, int limit = 1000}) Future<List<String>>
createObject({required String conversationKey, required String canvasId, required String objectId, required String objectType, required String createdByPeerKey, required Map<String, dynamic> transformJsonValue, required Map<String, dynamic> contentJsonValue, required Map<String, dynamic> styleJsonValue, required bool isDeleted}) Future<bool>
metadataWatermarks(String conversationKey, {required String canvasId}) Future<Map<String, String>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
objectWatermarks(String conversationKey, {required String canvasId}) Future<Map<String, String>>
snapshot(String conversationKey, {required String canvasId, required Iterable<String> objectIds, required Map<String, String> observedMetadataActorHlcWatermarks}) Future<CanvasSyncResponseModel>
toString() String
A string representation of this object.
inherited
updateMetadata({required String canvasId, required String conversationKey, required Map<String, dynamic> patch, String? hlcTimestamp}) Future<CanvasModel>
updateObjectRegister({required String conversationKey, required String canvasId, required String objectId, required String objectType, required String createdByPeerKey, required CanvasRegisterName registerName, Map<String, dynamic>? registerJsonValue, bool? isDeleted, String? hlcTimestamp}) Future<bool>

Operators

operator ==(Object other) bool
The equality operator.
inherited