CanvasSyncErrorModel class

Constructors

CanvasSyncErrorModel({required CanvasSyncErrorCode code, required String conversationKey, required String canvasId, int? objectCount, int? maxObjects, int? payloadBytes, int? maxPayloadBytes, String? message})
CanvasSyncErrorModel.fromJson(Json json)
factory

Properties

canvasId String
final
code CanvasSyncErrorCode
final
conversationKey String
final
hashCode int
The hash code for this object.
no setterinherited
maxObjects int?
final
maxPayloadBytes int?
final
message String?
final
objectCount int?
final
payloadBytes int?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Json
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited