CanvasSyncMetadataPayloadModel class

Constructors

CanvasSyncMetadataPayloadModel({required Map<String, dynamic> metadata, required String actorDeviceKey, required String hlcTimestamp, required String signature})
CanvasSyncMetadataPayloadModel.fromJson(Json json)
factory

Properties

actorDeviceKey String
final
hashCode int
The hash code for this object.
no setterinherited
hlcTimestamp String
final
metadata → Json
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
signature String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Json
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited