CanvasSyncResponseModel class
Constructors
-
CanvasSyncResponseModel({required List<
CanvasSyncObjectPayloadModel> objects, CanvasSyncMetadataPayloadModel? canvasMetadata}) - CanvasSyncResponseModel.fromJson(Json json)
-
factory
Properties
- canvasMetadata → CanvasSyncMetadataPayloadModel?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
objects
→ List<
CanvasSyncObjectPayloadModel> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Json -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited