Database class

The database service that handles all database operations.

Properties

caches Set<RepoCache>
final
canvas CanvasObjectsRepository
latefinal
canvases → CanvasesRepository
latefinal
canvasStateSync CanvasStateSyncRepository
latefinal
conversationParticipants → ConversationParticipantsRepository
latefinal
conversations → ConversationsRepository
latefinal
db ↔ Database
getter/setter pair
devices → DevicesRepository
latefinal
directory Directory
getter/setter pair
events → EventsRepository
latefinal
hashCode int
The hash code for this object.
no setterinherited
logs → EventLogsRepository
latefinal
messageGrants → MessageGrantsRepository
latefinal
messageReactions → MessageReactionsRepository
latefinal
messageReceipts → MessageReceiptsRepository
latefinal
messages → MessagesRepository
latefinal
peers → PeersRepository
latefinal
posts → PostsRepository
latefinal
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
spaces → SpacesRepository
latefinal

Methods

clear() Future<void>
init() Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
transaction<T>(Future<T> action()) Future<T>

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance Database
final