DeviceAuthEventBodyModel class

Inheritance

Constructors

DeviceAuthEventBodyModel({required String peerKey, required String peerSignature, required String deviceSigningKey, required String deviceEncryptionKey, required int timestamp, required String nodeId})
DeviceAuthEventBodyModel.fromJson(Map<String, dynamic> json)
factory

Properties

deviceEncryptionKey String
The encryption public key of the device that has been authorized.
final
deviceSigningKey String
The signing public key of the device that has been authorized.
final
hashCode int
The hash code for this object.
no setterinherited
nodeId String
The device's stable Tailscale node ID.
final
peerKey String
The peer's public signing key used to authorize the device on its behalf.
final
peerSignature String
The signature signed by the peer's public key of payload: "device_signing_key|device_encryption_key|timestamp"
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timestamp int
final
type EventType
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited
verify() Future<bool>
Verifies that the peer's signature authorizes this device.

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

create({required String nodeId, required String mnemonic}) Future<DeviceAuthEventBodyModel>