DeviceIdentityEventBodyModel class
- Inheritance
-
- Object
- EventBodyModel
- DeviceIdentityEventBodyModel
Constructors
- DeviceIdentityEventBodyModel({required String name, required String updatedDeviceKey})
- DeviceIdentityEventBodyModel.fromJson(Json json)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → EventType
-
finalinherited
- updatedDeviceKey → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Json -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited