lastValidEventHash property
The hash of the last valid event that the peer recognizes for the revoked device.
Implementation
final String? lastValidEventHash;
The hash of the last valid event that the peer recognizes for the revoked device.
final String? lastValidEventHash;