lastValidSequence property
The sequence number of the last valid event that the peer recognizes for the revoked device.
Implementation
final int? lastValidSequence;
The sequence number of the last valid event that the peer recognizes for the revoked device.
final int? lastValidSequence;