EventIngestor class

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

ingest(EventModel<EventBodyModel> event) Future<bool>
ingestAll(List<EventModel<EventBodyModel>> events) Future<({List<EventModel<EventBodyModel>> fail, List<EventModel<EventBodyModel>> success})>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance EventIngestor
final