EventsClient class

Constructors

EventsClient()

Properties

client TailscaleClient
latefinalinherited
db Database
no setterinherited
encryption Encryption
latefinalinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
signing Signing
latefinalinherited

Methods

clear() → void
inherited
get(String ip, String path, {Map<String, String>? headers}) Future<Response>
inherited
init() Future<void>
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
post(String ip, String path, {Map<String, String>? headers, Map<String, dynamic>? body}) Future<Response>
inherited
publish<T extends EventBodyModel>(T body) Future<EventModel<EventBodyModel>>
Publishes a new event to the network. Returns the event if it was successfully published, null otherwise.
relay(EventModel<EventBodyModel> event, [int k = 4]) Future<void>
Relays an existing event to K random peers in a Gossip-style fanout. Returns whether the event was able to be relayed to a peer.
relayDevice(String deviceKey, EventModel<EventBodyModel> event) Future<EventModel<EventBodyModel>?>
relayIP(String ip, EventModel<EventBodyModel> event) Future<EventModel<EventBodyModel>?>
syncDevice(String deviceKey) Future<void>
Attempts a sync with the provided device key. Canceled if the device is not online.
syncIP(String ip) Future<void>
Syncs events with the given client identified by the given IP.
syncRandom() Future<void>
Performs a sync with a randomly selected online device.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited