FileSecretStorage class final

File-backed secret storage used by test hosts that need values to survive a process restart, such as the spawned P2P peer runtime.

Constructors

FileSecretStorage(String rootPath)

Properties

hashCode int
The hash code for this object.
no setterinherited
rootPath String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

delete(String key) Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
read(String key) Future<String?>
toString() String
A string representation of this object.
inherited
write(String key, String value) Future<void>

Operators

operator ==(Object other) bool
The equality operator.
inherited