keys property

Map<String, String> keys
final

The index of recipient device public signing keys to the session key, each encrypted with the device's public encryption key.

Implementation

final Map<String, String> keys;