Messenger class

The messenger is used to send/open message events between clients.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

markAllRead(Iterable<MessageModel<MessagePayloadModel>> messages) Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
open(MessageEventModel event) Future<void>
Opens a message event, decrypting it if it is for this peer and updating the peer's local conversation and message tables.
openFileAttachment(String messageHash, NetworkMediaModel attachment) Future<Uint8List?>
openImageAttachment(String messageHash, NetworkMediaModel attachment) Future<Uint8List?>
openReaction(MessageReactionEventModel event) Future<void>
openSecretKey(MessageEventModel event) Future<SecretKey?>
Opens the secret key for a message event. This is typically done by decrypting the shared secret key for this device, or if this device was not originally included in the list of recipients for the message, than through a message grant this device has received. If neither are possible, it returns null.
send(MessagePayloadModel payload, {required List<String> recipients, List<File> files = const []}) Future<void>
sendCanvasCreatedMessage({required List<String> recipients}) Future<void>
sendReaction(String messageHash, {required String symbol}) Future<void>
sendTextMessage(String text, {required List<String> recipients, List<File> files = const []}) Future<void>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance Messenger
final