PostEventBodyModel class

Inheritance

Constructors

PostEventBodyModel({required String text, String? replyTo, String? rootHash, List<NetworkMediaModel> attachments = const []})
PostEventBodyModel.fromJson(Json json)
factory

Properties

attachments List<NetworkMediaModel>
final
hashCode int
The hash code for this object.
no setterinherited
replyTo String?
final
rootHash String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text String
final
type EventType
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Json
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited