SessionValue class

Constructors

SessionValue(String key)

Properties

hashCode int
The hash code for this object.
no setterinherited
key String
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String?
no setterinherited

Methods

clear() Future<void>
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
read() Future<String?>
inherited
toString() String
A string representation of this object.
inherited
write(String updatedValue) Future<String>
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

clearAll() Future<void>