Signing class

Properties

hashCode int
The hash code for this object.
no setterinherited
publicKey String
The public signing key for the device.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createPeerMnemonic() Future<String>
Generates a random 12-word mnemonic for a peer. The mnemonic is used to generate the peer's master signing key. It is never persisted and the peer must keep it secure themselves in order to authorize and revoke their devices.
getPeerPublicKey(String mnemonic) Future<String>
Returns the public signing key for the peer given their saved mnemonic.
hash(String message) Future<String>
Hashes a given message.
override
init() Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parsePublicKey(String publicKeyStr) → SimplePublicKey
parseSignature(String signatureStr, String publicKeyStr) → Signature
signDeviceMessage(String message) Future<String>
Signs a message with the device's public signing key.
signPeerMessage(String mnemonic, String message) Future<String>
Signs a message using the peer's master signing key. The peer's signing key is always regenerated on the fly from the peer's secret mnemonic.
toString() String
A string representation of this object.
inherited
verify({required String message, required String signature, required String publicKey}) Future<bool>
Verifies whether a message was signed with the given signature.

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance Signing
final