createPeerMnemonic method

Future<String> createPeerMnemonic()

Generates a random 12-word mnemonic for a peer. The mnemonic is used to generate the peer's master signing key. It is never persisted and the peer must keep it secure themselves in order to authorize and revoke their devices.

Implementation

Future<String> createPeerMnemonic() async {
  return bip39.generateMnemonic();
}