SpaceIdentityEventBodyModel class

Inheritance

Constructors

SpaceIdentityEventBodyModel({required String name, required String description, NetworkMediaModel? image})
SpaceIdentityEventBodyModel.fromJson(Json json)
factory

Properties

description String
final
hashCode int
The hash code for this object.
no setterinherited
image NetworkMediaModel?
final
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type EventType
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Json
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited