TailscaleClient class

The client service that handles connecting to the tailnet and publishing events to other peers.

Properties

admin → AdminClient
latefinal
canvas → CanvasClient
latefinal
changes Stream<TailscaleClient>
no setter
clientId String
no setter
defaultControlUrlOverride Uri?
getter/setter pair
encryption Encryption
final
events EventsClient
latefinal
hashCode int
The hash code for this object.
no setterinherited
identity → IdentityClient
latefinal
isRunning bool
no setter
logger Logger
final
media → MediaClient
latefinal
messages → MessagesClient
latefinal
peerPublicKey String?
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
signing Signing
final
state → NodeState
no setter
subclients List<BaseClient>
latefinal

Methods

addDevice({required String authKey, required String peerKey, required String adminPublicKey, required String peerMnemonic, String? deviceName}) Future<void>
connect({String? authKey, Uri? controlUrl}) Future<void>
disconnect() Future<void>
generateClientId() String
get(String ip, String path, {Map<String, String>? headers}) Future<Response>
getCurrentIp() Future<String?>
getCurrentNodeId() Future<String?>
getCurrentStatus() Future<TailscaleStatus?>
getNodeByIp(String ip, {bool refresh = false}) Future<TailscaleNode?>
getNodes({bool refresh = false}) Future<List<TailscaleNode>>
getStatus() Future<TailscaleStatus>
init({bool reconnectIfStopped = true}) Future<void>
logout() Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
post(String ip, String path, {Map<String, String>? headers, Map<String, dynamic>? body}) Future<Response>
postJson(String ip, String path, {Map<String, String>? headers, Map<String, dynamic>? body}) Future<TailscaleHttpResponse>
setPeer(String publicKey) Future<void>
setPeerPublicKeyForTest(String key) Future<void>
sync() Future<void>
syncDevice(String deviceKey) Future<void>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

debugEngineOverride ↔ Tailscale?
getter/setter pair
engine ← Tailscale
no getter
instance TailscaleClient
getter/setter pair