DuneNetworkState enum
Stable public view of the local Dune network lifecycle.
This intentionally avoids exposing the transport package's lifecycle enum through the app-facing SDK surface.
Values
- unknown → const DuneNetworkState
- notConfigured → const DuneNetworkState
- needsLogin → const DuneNetworkState
- needsMachineAuth → const DuneNetworkState
- starting → const DuneNetworkState
- running → const DuneNetworkState
- stopped → const DuneNetworkState
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- isRunning → bool
-
no setter
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
DuneNetworkState> - A constant List of the values in this enum, in order of their declaration.