SpacesApi class final
Public API for the current Dune space.
Constructors
- SpacesApi()
-
const
Properties
-
current
→ Query<
SpaceModel?> -
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
createInviteLink(
) → Future< PeerInviteLink> -
initialize(
{required String name, String description = '', NetworkMediaModel? image}) → Future< void> -
join(
PeerInviteLink invite) → Future< void> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
updateProfile(
{required String name, String description = '', NetworkMediaModel? image}) → Future< void>
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited