dune_core_testing_internals library

Classes

AdminApi
Public API for tailnet admin configuration and credentials.
AuthKeyRequestLogBodyModel
CanvasAnchorKeyCache
In-memory cache of opened anchor secret keys for canvases.
CanvasApi
Public API for canvas metadata, object projections, content, media, and sync.
CanvasContentApi
Content encryption helpers for encrypted canvas objects and blobs.
CanvasHlc
CanvasHlcGenerator
CanvasMediaApi
Canvas media helpers. Canvas media is encrypted before durable storage.
CanvasMessageModel
CanvasMessagePayloadModel
CanvasModel
CanvasObjectRecordModel
CanvasObjectsApi
Public object queries and local object mutations for conversation canvases.
CanvasObjectSnapshot
CanvasObjectsRepository
CanvasRegisterClockModel
A signed merge clock for a single canvas object register.
CanvasRegisterState
Public merge metadata for the current value of one canvas object register.
CanvasStateSyncRepository
Current-state synchronization for canvases.
CanvasSyncApi
Screen-scoped canvas peer sync helpers.
CanvasSyncErrorModel
CanvasSyncMetadataPayloadModel
CanvasSyncObjectPayloadModel
CanvasSyncRequestModel
CanvasSyncResponseModel
ConversationModel
ConversationParticipantModel
ConversationReceiptsRequestModel
ConversationReceiptsResponseModel
ConversationsApi
Public query API for conversations and participants.
Database
The database service that handles all database operations.
DeleteMessageEventBodyModel
DeviceAuthEventBodyModel
DeviceAuthorization
DeviceIdentityEventBodyModel
DeviceModel
DeviceRequestBindingModel
DeviceRestoreResult
DeviceRevokeEventBodyModel
DevicesApi
Public API for device reads, device onboarding, and device lifecycle.
DeviceSelfRevokeEventBodyModel
A device has self-revoked itself from the tailnet. This is similar to DeviceRevokeEventBodyModel, except that it doesn't require peer-verification since any device is authorized to revoke itself.
DirectoryConfig
Host-provided filesystem locations used by the Dune runtime.
DraftEventModel<T extends EventBodyModel>
Dune
Host-provided configuration for the Dune core runtime.
DuneExceptionCode
Stable error codes surfaced by the public Dune SDK.
DuneNetworkStatus
Public transport-agnostic view of the local Dune network status.
DuneRuntimeStorageStats
DuneSearchResults
DuneTesting
Testing-only hooks for resetting global runtime bookkeeping in process.
Encryption
EventBodyModel
EventIngestor
EventLogModel
EventModel<T extends EventBodyModel>
EventsClient
FileSecretStorage
File-backed secret storage used by test hosts that need values to survive a process restart, such as the spawned P2P peer runtime.
FixedDirectoryConfig
Fixed host-provided storage paths used by tests and custom hosts.
IdentifyLogBodyModel
InMemorySecretStore
LogBodyModel
Logger
LogsApi
Public diagnostics query API for Dune event logs.
LoopbackTailscale
Minimal tailscale engine used for multi-process loopback tests.
MediaApi
Public API for durable Dune media storage and peer media fetches.
MediaStorage
Persistent encrypted content-addressed media storage.
MessageEventBodyModel
The body of a message event. The message's payload is encrypted in payload using a one-time symmetric encryption key.
MessageGrantModel
MessageModel<T extends MessagePayloadModel>
MessageNetworkMediaModel
MessagePayloadModel
MessageQuery
Lazy, composable query builder for decrypted message projections.
MessageReactionEventBodyModel
MessageReactionModel
MessageReceiptModel
MessageReceiptSyncResult
Result of asking a peer for updated read receipts.
MessagesApi
Public API for message reads and message-oriented commands.
Messenger
The messenger is used to send/open message events between clients.
NetworkApi
Public network lifecycle API.
NetworkMediaModel
NetworkSnapshot
Snapshot of the local Dune network runtime.
PeerIdentityEventBodyModel
PeerMetaDataModel
PeerModel
PeerRevokeEventBodyModel
A peer has been revoked from the tailnet. All of the peer's devices are revoked from the network and no future devices identifying as this peer will be permitted to join.
PeersApi
Public API for peer reads and peer lifecycle commands.
PeerServer
PostEventBodyModel
PostMaster
PostModel
PostNetworkMediaModel
PostsApi
Public API for post reads and post publishing commands.
ProtocolDomains
Signed or KDF domain strings that are part of the wire contract.
ProtocolVersions
Version constants for Dune wire-format surfaces.
PublishReceivedLogBodyModel
Query<T>
Public reactive query handle returned by Dune resource APIs.
RuntimeApi
Public runtime lifecycle and host-configuration API.
SearchApi
Public cross-resource search API.
SessionValue
Signing
SpaceIdentityEventBodyModel
SpaceModel
SpacesApi
Public API for the current Dune space.
SyncReceivedLogBodyModel
SyncSentLogBodyModel
TailscaleAdmin
The admin service for managing the tailscale network.
TailscaleClient
The client service that handles connecting to the tailnet and publishing events to other peers.
TemporaryDirectoryConfig
Unique temp-backed paths used when a host has not supplied real storage.
TextMessageModel
TextMessagePayloadModel
UnknownMessageModel
UnknownMessagePayloadModel

Enums

CanvasRegisterName
CanvasSyncErrorCode
CanvasSyncResult
Result of syncing a conversation canvas with a peer.
DuneNetworkState
Stable public view of the local Dune network lifecycle.
EventLogTypes
EventType
MessageOrder
MessageReceiptStatus
MessageTypes

Extensions

QueryExtensions on Query<List<T>>

Functions

canonicalJsonEncode(Object? value) String
Encodes the restricted Dune Canonical JSON v1 profile.
canonicalJsonFromString(String source) String
Parses source and re-encodes it using Dune Canonical JSON v1.

Exceptions / Errors

CanvasAnchorUnavailableException
DuneException
Public exception type for actionable SDK failures.