CanvasSyncObjectPayloadModel class
Constructors
-
CanvasSyncObjectPayloadModel({required CanvasObjectRecordModel object, required List<
CanvasRegisterClockModel> registerClocks}) - CanvasSyncObjectPayloadModel.fromJson(Json json)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- object → CanvasObjectRecordModel
-
final
-
registerClocks
→ List<
CanvasRegisterClockModel> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Json -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited