CanvasSyncRequestModel class
Constructors
-
CanvasSyncRequestModel({required String conversationKey, required String canvasId, required Map<
String, String> objectActorHlcWatermarks, required Map<String, String> metadataActorHlcWatermarks}) - CanvasSyncRequestModel.fromJson(Json json)
-
factory
Properties
- canvasId → String
-
final
- conversationKey → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
metadataActorHlcWatermarks
→ Map<
String, String> -
final
-
objectActorHlcWatermarks
→ Map<
String, String> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Json -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited