DeviceRevokeEventBodyModel class
- Inheritance
-
- Object
- EventBodyModel
- DeviceRevokeEventBodyModel
Constructors
- DeviceRevokeEventBodyModel({required String peerKey, required String peerSignature, required String revokedDeviceKey, required DateTime timestamp, String? lastValidEventHash, int? lastValidSequence})
-
DeviceRevokeEventBodyModel.fromJson(Map<
String, dynamic> json) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- lastValidEventHash → String?
-
The hash of the last valid event that the peer recognizes for the revoked device.
final
- lastValidSequence → int?
-
The sequence number of the last valid event that the peer recognizes for the revoked device.
final
- peerKey → String
-
The peer's public signing key used to authorize the revocation of this device.
final
- peerSignature → String
-
The signature signed by the peer's public key of payload: "revoked_device_key|timestamp|last_valid_event_hash|last_valid_sequence"
final
- revokedDeviceKey → String
-
The public signing key of the device that has been revoked.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timestamp → DateTime
-
final
- type → EventType
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
-
verify(
) → Future< bool> - Verifies that the peer's signature authorized revoking the specified device.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
create(
{required String mnemonic, required String revokedDeviceKey}) → Future< DeviceRevokeEventBodyModel>