DeviceSelfRevokeEventBodyModel class
A device has self-revoked itself from the tailnet. This is similar to DeviceRevokeEventBodyModel, except that it doesn't require peer-verification since any device is authorized to revoke itself.
- Inheritance
-
- Object
- EventBodyModel
- DeviceSelfRevokeEventBodyModel
Constructors
- DeviceSelfRevokeEventBodyModel({required String? lastValidEventHash, required int? lastValidSequence, required DateTime timestamp})
-
DeviceSelfRevokeEventBodyModel.fromJson(Map<
String, dynamic> json) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- lastValidEventHash → String?
-
The hash of the last valid event that the peer recognizes for the revoked device.
final
- lastValidSequence → int?
-
The sequence number of the last valid event that the peer recognizes for the revoked device.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timestamp → DateTime
-
final
- type → EventType
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Json -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited