DraftEventModel<T extends EventBodyModel> class
- Implementers
Constructors
Properties
- body → T
-
final
- deviceKey → String
-
The device's public signing key used to sign the event.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- nonce → String
-
final
- prevHash → String?
-
The hash of the previous event in the sender's event chain. Not present for the device's genesis event.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sequence → int
-
A sequence number used to order events from this sender.
final
- timestamp → DateTime
-
final
- type → EventType
-
no setter
- unsignedMessage → String
-
latefinal
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited