Encryption class
Methods
-
createSecretKey()
→ Future<SecretKey>
-
-
decryptSecret(SecretKey secretKey, String ciphertext, {List<int> aad = const []})
→ Future<String>
-
Decrypts a message with the given symmetric secret key.
-
decryptSecretBytes(SecretKey secretKey, List<int> bytes, {List<int>? aad})
→ Future<List<int>>
-
Decrypts bytes from the given symmetric secret key.
-
decryptSharedSecret(List<int> bytes, String senderPublicKey)
→ Future<List<int>>
-
Decrypts shared secret
bytes from the remote sender using their encryption
public key and the current peer's encryption private key.
-
encryptSecret(SecretKey secretKey, String message, {List<int>? aad})
→ Future<String>
-
Encrypts a message with the given symmetric secret key.
-
encryptSecretBytes(SecretKey key, List<int> bytes, {List<int>? aad})
→ Future<List<int>>
-
Encrypts bytes with the given symmetric secret key and returns the raw ciphertext bytes.
-
encryptSharedSecret(List<int> bytes, String recipientPublicKey)
→ Future<List<int>>
-
Encrypts shared secret
bytes to share with the remote recipient using their encryption public key
and the current peer's encryption private key.
-
init()
→ Future<void>
-
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
parsePublicKey(String encoded)
→ SimplePublicKey
-
Parses a base64 encoded public key into a
SimplePublicKey.
-
toString()
→ String
-
A string representation of this object.
inherited