EventIngestor class
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
ingest(
EventModel< EventBodyModel> event) → Future<bool> -
ingestAll(
List< EventModel< events) → Future<EventBodyModel> >({List< EventModel< fail, List<EventBodyModel> >EventModel< success})>EventBodyModel> > -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance → EventIngestor
-
final