signature property
The signature of the event signed using the deviceKey of the unsignedMessage. Event bodies that require peer-level authority carry their own peer signature in the typed payload.
Implementation
final String signature;
The signature of the event signed using the deviceKey of the unsignedMessage. Event bodies that require peer-level authority carry their own peer signature in the typed payload.
final String signature;