responseTimeout property
Maximum idle time to wait for a loopback peer response.
Some deterministic peer routes still perform comparatively slow work, so this is intentionally longer than the local socket connect timeout.
Implementation
final Duration responseTimeout;