MessageGrantModel class
Constructors
- MessageGrantModel({required String hash, required String issuerEncryptionKey, required String encryptedSecretKey})
-
MessageGrantModel.fromJson(Map<
String, dynamic> json) -
factory
Properties
- encryptedSecretKey → String
-
final
- hash → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- issuerEncryptionKey → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited