MessageReactionEventBodyModel class
- Inheritance
-
- Object
- EventBodyModel
- MessageReactionEventBodyModel
Constructors
- MessageReactionEventBodyModel({required String hash, required String ciphertext})
- MessageReactionEventBodyModel.fromJson(Json json)
-
factory
Properties
- ciphertext → String
-
final
- hash → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → EventType
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Json -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited