PeerRevokeEventBodyModel class

A peer has been revoked from the tailnet. All of the peer's devices are revoked from the network and no future devices identifying as this peer will be permitted to join.

Inheritance

Constructors

PeerRevokeEventBodyModel({required String peerKey, required String revokedPeerKey, required String peerSignature, required DateTime timestamp})
PeerRevokeEventBodyModel.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
peerKey String
The peer's public signing key used to authorize the revocation of this peer.
final
peerSignature String
The signature signed by the peer's public key of payload: "revoked_peer_key|timestamp"
final
revokedPeerKey String
The public signing key of the peer that has been revoked.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timestamp DateTime
final
type EventType
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Json
override
toString() String
A string representation of this object.
inherited
verify() Future<bool>
Verifies that the admin peer's signature authorized revoking the revoked peer.

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

create({required String mnemonic, required String revokedPeerKey}) Future<PeerRevokeEventBodyModel>