PeerServer class
Properties
- client → TailscaleClient
-
latefinal
- hashCode → int
-
The hash code for this object.
no setterinherited
- logger → Logger
-
final
- middleware → PeerServerMiddleware
-
latefinal
- port → int
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
start(
) → Future< void> -
stop(
) → Future< void> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance → PeerServer
-
final