TailscaleAdmin class
The admin service for managing the tailscale network.
Properties
- adminApiKey → String?
-
no setter
- adminPublicKey → String?
-
no setter
-
changes
→ Stream<
TailscaleAdmin> -
no setter
-
generateAuthKeyOverride
↔ Future<
String> Function({required String apiKey, required String tailnetId})? -
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- isAdmin → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tailnetId → String?
-
no setter
Methods
-
clear(
) → Future< void> -
deleteDevice(
String deviceKey) → Future< void> - Permanently deletes a device from the tailnet.
-
generateAuthKey(
{required String apiKey, required String tailnetId}) → Future< String> - Generates an auth key locally on the client. The generated auth key can then be used to connect to the given tailnet. This is done by the tailnet admin when connecting themselves to the tailnet, as well as for generating one-time invite links to invite others.
-
init(
) → Future< void> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
resetTestOverrides(
) → void -
setAdminPeer(
String adminPeerKey) → Future< void> -
setupNetwork(
{required String apiKey, required String tailnetId}) → Future< void> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance → TailscaleAdmin
-
final